@@ -14,13 +14,13 @@ def pymigration():
 
     parser = ArgumentParser(description="Parameters to migrate.")
     parser.add_argument("-u", "--up", dest="up", default=False, action="store_true",
-                      help="Execute python methods to upgrade shema of sistem.")
+                      help="Execute python methods to upgrade schema of system.")
 
     parser.add_argument("--no-exec", default=True, dest="execute", action="store_false",
                         help="If you want only see the list of migrantions command.")
 
     parser.add_argument("-d", "--down", dest="down", default=False, action="store_true",
-                      help="Displays simple-db-migrate's version and exit.")
+                      help="Execute python methods to downgrade schema of system.")
 
     parser.add_argument("-c", "--current-version", dest="current_version", default=False,
                       help="Version of actual migration.", action="store_true")
@@ -41,9 +41,12 @@ def pymigration():
 
     if args.down:
         try:
-            for migration in migrations.down_migrations():
-                migration.down()
-                terminal_message.down_message(migration)
+            if list(migrations.down_migrations()):
+                for migration in migrations.down_migrations():
+                    migration.down()
+                    terminal_message.down_message(migration)
+            else:
+                print "No migrations need to be executed, already in %s version." % Version().get_current()
         except Exception, e:
             terminal_message.error_message_down(migration, e)
             sys.exit()
@@ -51,9 +54,12 @@ def pymigration():
 
     if args.up:
         try:
-            for migration in migrations.up_migrations():
-                migration.up()
-                terminal_message.up_message(migration)
+            if list(migrations.up_migrations()):
+                for migration in migrations.up_migrations():
+                    migration.up()
+                    terminal_message.up_message(migration)
+            else:
+                print "No migrations need to be executed, already in %s version." % Version().get_current()
         except Exception, e:
             terminal_message.error_message_up(migration, e)
 
@@ -77,4 +83,4 @@ def pymigration():
                 except Exception, e:
                     terminal_message.error_message_down(migration, e)
                     sys.exit()
-        Version().set_current(args.version_to)
\ No newline at end of file
+        Version().set_current(args.version_to)
